@@ -21,6 +21,7 @@ from zope.globalrequest import getRequest
 from zope.interface.interfaces import IInterface
 
 import pkg_resources
+import six
 
 
 logger = getLogger('plone.api.portal')
@@ -191,7 +192,7 @@ def send_email(
 
     # If the mail headers are not properly encoded we need to extract
     # them and let MailHost manage the encoding.
-    if isinstance(body, unicode):
+    if isinstance(body, six.text_type):
         body = body.encode(encoding)
 
     host = get_tool('MailHost')
@@ -441,7 +442,7 @@ def translate(msgid, domain='plone', lang=None):
     :param lang: target language
     :type lang: string
     :returns: translated message
-    :rtype: unicode
+    :rtype: six.text_type
     :Example: :ref:`portal_translate_example`
     """
     translation_service = get_tool('translation_service')
