@@ -143,6 +143,20 @@ class TestPloneApiEnv(unittest.TestCase):
             ])
         self.test_test_defaults()
 
+    def test_adopt_manager_string_role(self):
+        """Test that we can adopt the Manager role temporarily."""
+        with api.env.adopt_roles(roles='Manager'):
+            self.should_allow([
+                'public_method',
+                'pp_method',
+                'qq_method',
+                'rr_method',
+            ])
+            self.should_forbid([
+                'private_method',
+            ])
+        self.test_test_defaults()
+
     def test_adopt_fewers_role(self):
         """Test that we can adopt a non-Manager role temporarily."""
         with api.env.adopt_roles(roles=['Member']):
@@ -402,6 +416,12 @@ class TestPloneApiEnv(unittest.TestCase):
         from plone.api.env import test_mode
         self.assertEqual(test_mode(), True)
 
+    def test_read_only_mode(self):
+        """Test that read_only_mode() returns False
+        as we have a write enabled ZODB."""
+        from plone.api.env import read_only_mode
+        self.assertFalse(read_only_mode())
+
     def test_plone_version(self):
         """Tests that plone_version() returns Plone version."""
         from plone.api.env import plone_version
@@ -411,7 +431,7 @@ class TestPloneApiEnv(unittest.TestCase):
         # When run against coredev, we may have a .devN suffix as well.
         self.assertRegexpMatches(
             plone_version(),
-            '^(\d+\.\d+|\d+\.\d+\.\d+)(a\d+|b\d+|rc\d+)?(\.dev\d)?$'
+            '^(\d+\.\d+|\d+\.\d+\.\d+)(a\d+|b\d+|rc\d+)?(\.dev\d)?$',
         )
 
     def test_zope_version(self):
@@ -422,7 +442,7 @@ class TestPloneApiEnv(unittest.TestCase):
         # it could also include a package status id (Alpha, Beta or RC)
         self.assertRegexpMatches(
             zope_version(),
-            '^(\d+\.\d+|\d+\.\d+\.\d+)(a\d+|b\d+|rc\d+)?(\.dev\d)?$'
+            '^(\d+\.\d+|\d+\.\d+\.\d+)(a\d+|b\d+|rc\d+)?(\.dev\d)?$',
         )
 
     def test_adopt_user_different_username(self):
